﻿/// <reference path="data.js" />

(function (lightSwitchApplication) {

    var $Screen = msls.Screen,
        $defineScreen = msls._defineScreen,
        $DataServiceQuery = msls.DataServiceQuery,
        $toODataString = msls._toODataString,
        $defineShowScreen = msls._defineShowScreen;

    function BrowseCustomers(parameters, dataWorkspace) {
        /// <summary>
        /// Represents the BrowseCustomers screen.
        /// </summary>
        /// <param name="parameters" type="Array">
        /// An array of screen parameter values.
        /// </param>
        /// <param name="dataWorkspace" type="msls.application.DataWorkspace" optional="true">
        /// An existing data workspace for this screen to use. By default, a new data workspace is created.
        /// </param>
        /// <field name="Customers" type="msls.VisualCollection">
        /// Gets the customers for this screen.
        /// </field>
        /// <field name="details" type="msls.application.BrowseCustomers.Details">
        /// Gets the details for this screen.
        /// </field>
        if (!dataWorkspace) {
            dataWorkspace = new lightSwitchApplication.DataWorkspace();
        }
        $Screen.call(this, dataWorkspace, "BrowseCustomers", parameters);
    }

    function ViewCustomerDetail(parameters, dataWorkspace) {
        /// <summary>
        /// Represents the ViewCustomerDetail screen.
        /// </summary>
        /// <param name="parameters" type="Array">
        /// An array of screen parameter values.
        /// </param>
        /// <param name="dataWorkspace" type="msls.application.DataWorkspace" optional="true">
        /// An existing data workspace for this screen to use. By default, a new data workspace is created.
        /// </param>
        /// <field name="Customer" type="msls.application.Customer">
        /// Gets or sets the customer for this screen.
        /// </field>
        /// <field name="Orders" type="msls.VisualCollection">
        /// Gets the orders for this screen.
        /// </field>
        /// <field name="details" type="msls.application.ViewCustomerDetail.Details">
        /// Gets the details for this screen.
        /// </field>
        if (!dataWorkspace) {
            dataWorkspace = new lightSwitchApplication.DataWorkspace();
        }
        $Screen.call(this, dataWorkspace, "ViewCustomerDetail", parameters);
    }

    function OrderDetail(parameters, dataWorkspace) {
        /// <summary>
        /// Represents the OrderDetail screen.
        /// </summary>
        /// <param name="parameters" type="Array">
        /// An array of screen parameter values.
        /// </param>
        /// <param name="dataWorkspace" type="msls.application.DataWorkspace" optional="true">
        /// An existing data workspace for this screen to use. By default, a new data workspace is created.
        /// </param>
        /// <field name="Order" type="msls.application.Order">
        /// Gets or sets the order for this screen.
        /// </field>
        /// <field name="Order_Details" type="msls.VisualCollection">
        /// Gets the order_Details for this screen.
        /// </field>
        /// <field name="details" type="msls.application.OrderDetail.Details">
        /// Gets the details for this screen.
        /// </field>
        if (!dataWorkspace) {
            dataWorkspace = new lightSwitchApplication.DataWorkspace();
        }
        $Screen.call(this, dataWorkspace, "OrderDetail", parameters);
    }

    function CustomerDetail(parameters, dataWorkspace) {
        /// <summary>
        /// Represents the CustomerDetail screen.
        /// </summary>
        /// <param name="parameters" type="Array">
        /// An array of screen parameter values.
        /// </param>
        /// <param name="dataWorkspace" type="msls.application.DataWorkspace" optional="true">
        /// An existing data workspace for this screen to use. By default, a new data workspace is created.
        /// </param>
        /// <field name="Customer" type="msls.application.Customer">
        /// Gets or sets the customer for this screen.
        /// </field>
        /// <field name="details" type="msls.application.CustomerDetail.Details">
        /// Gets the details for this screen.
        /// </field>
        if (!dataWorkspace) {
            dataWorkspace = new lightSwitchApplication.DataWorkspace();
        }
        $Screen.call(this, dataWorkspace, "CustomerDetail", parameters);
    }

    msls._addToNamespace("msls.application", {

        BrowseCustomers: $defineScreen(BrowseCustomers, [
            {
                name: "Customers", kind: "collection", elementType: lightSwitchApplication.Customer,
                createQuery: function () {
                    return this.dataWorkspace.NorthwindData.Customers;
                }
            }
        ], [
        ]),

        ViewCustomerDetail: $defineScreen(ViewCustomerDetail, [
            { name: "Customer", kind: "local", type: lightSwitchApplication.Customer },
            {
                name: "Orders", kind: "collection", elementType: lightSwitchApplication.Order,
                getNavigationProperty: function () {
                    if (this.owner.Customer) {
                        return this.owner.Customer.details.properties.Orders;
                    }
                    return null;
                }
            }
        ], [
        ]),

        OrderDetail: $defineScreen(OrderDetail, [
            { name: "Order", kind: "local", type: lightSwitchApplication.Order },
            {
                name: "Order_Details", kind: "collection", elementType: lightSwitchApplication.Order_Detail,
                getNavigationProperty: function () {
                    if (this.owner.Order) {
                        return this.owner.Order.details.properties.Order_Details;
                    }
                    return null;
                }
            }
        ], [
        ]),

        CustomerDetail: $defineScreen(CustomerDetail, [
            { name: "Customer", kind: "local", type: lightSwitchApplication.Customer }
        ], [
        ]),

        showBrowseCustomers: $defineShowScreen(function showBrowseCustomers(boundaryOption, options) {
            /// <summary>
            /// Asynchronously navigates forward to the BrowseCustomers screen.
            /// </summary>
            /// <param name="boundaryOption" type="String">
            /// A boundary option (from msls.BoundaryOption) that specifies the behavior when navigating to or returning from the target screen.
            /// </param>
            /// <param name="options" optional="true">
            /// An object that provides one or more of the following options:<br/>- beforeShown: a function that is called after boundary behavior has been applied but before the screen is shown.
            /// </param>
            /// <returns type="WinJS.Promise" />
            var parameters = Array.prototype.slice.call(arguments, 1, 1);
            return lightSwitchApplication.showScreen("BrowseCustomers", boundaryOption, parameters, options);
        }),

        showViewCustomerDetail: $defineShowScreen(function showViewCustomerDetail(boundaryOption, Customer, options) {
            /// <summary>
            /// Asynchronously navigates forward to the ViewCustomerDetail screen.
            /// </summary>
            /// <param name="boundaryOption" type="String">
            /// A boundary option (from msls.BoundaryOption) that specifies the behavior when navigating to or returning from the target screen.
            /// </param>
            /// <param name="options" optional="true">
            /// An object that provides one or more of the following options:<br/>- beforeShown: a function that is called after boundary behavior has been applied but before the screen is shown.
            /// </param>
            /// <returns type="WinJS.Promise" />
            var parameters = Array.prototype.slice.call(arguments, 1, 2);
            return lightSwitchApplication.showScreen("ViewCustomerDetail", boundaryOption, parameters, options);
        }),

        showOrderDetail: $defineShowScreen(function showOrderDetail(boundaryOption, Order, options) {
            /// <summary>
            /// Asynchronously navigates forward to the OrderDetail screen.
            /// </summary>
            /// <param name="boundaryOption" type="String">
            /// A boundary option (from msls.BoundaryOption) that specifies the behavior when navigating to or returning from the target screen.
            /// </param>
            /// <param name="options" optional="true">
            /// An object that provides one or more of the following options:<br/>- beforeShown: a function that is called after boundary behavior has been applied but before the screen is shown.
            /// </param>
            /// <returns type="WinJS.Promise" />
            var parameters = Array.prototype.slice.call(arguments, 1, 2);
            return lightSwitchApplication.showScreen("OrderDetail", boundaryOption, parameters, options);
        }),

        showCustomerDetail: $defineShowScreen(function showCustomerDetail(boundaryOption, Customer, options) {
            /// <summary>
            /// Asynchronously navigates forward to the CustomerDetail screen.
            /// </summary>
            /// <param name="boundaryOption" type="String">
            /// A boundary option (from msls.BoundaryOption) that specifies the behavior when navigating to or returning from the target screen.
            /// </param>
            /// <param name="options" optional="true">
            /// An object that provides one or more of the following options:<br/>- beforeShown: a function that is called after boundary behavior has been applied but before the screen is shown.
            /// </param>
            /// <returns type="WinJS.Promise" />
            var parameters = Array.prototype.slice.call(arguments, 1, 2);
            return lightSwitchApplication.showScreen("CustomerDetail", boundaryOption, parameters, options);
        })

    });

}(msls.application));
